JoyMenu constructor
const
JoyMenu({
- Key? key,
- required List<
JoyMenuItem> items, - Color? hoverColor,
- Color? defaultColor,
It is a meth to make beautiful lists, and fast, without the need to configure many decorations.
Widget that can be set in the menu property of the
JoyDropDown.list(menu: JoyMenu(...), ...)
Here are some possible settings:
menuDecoration: The decoration of the menu. (Its a Container)hoverColor: The color of the menu when the mouse is over it.defaultColor: The color of the menu when the mouse is not over it.items: A list that should be of type List
Implementation
const JoyMenu({
Key? key,
required this.items,
this.hoverColor,
this.defaultColor,
this.menuDecoration,
}) : super(key: key);