JoyMenuItem class

Constructors

JoyMenuItem({required Icon icon, required Text title, Text? subtitle, required void onTap()})

Properties

hashCode int
The hash code for this object.
no setterinherited
icon Icon
final
onTap → void Function()
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle Text?
final
title Text
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited