JoyMenuItem constructor
It's like listile, only it has the properties a navMenu needs!
icon: The icon of the menu item.title: The title of the menu item.onTap: The function that will be called when the menu item is tapped.
Implementation
JoyMenuItem({
required this.icon,
required this.title,
required this.onTap,
});